@@ -529,7 +529,7 @@ def weather_deal(wthlist):
             wth.temp = temp
             wthlist[0] = wth
 
-if __name__ == '__main__':
+def Start():
     multiprocessing.freeze_support()
     print("开始程序...")
     mylist = multiprocessing.Manager().list()
